summaryrefslogtreecommitdiff
path: root/sys/netinet/tcp_var.h
diff options
context:
space:
mode:
authorMarkus Friedl <markus@cvs.openbsd.org>2004-01-31 19:40:11 +0000
committerMarkus Friedl <markus@cvs.openbsd.org>2004-01-31 19:40:11 +0000
commit5acc69ea30347286938376b652ffd9344ea3775f (patch)
tree6ca73f15815cb7f1c492c8d18c14ecdabc0e404b /sys/netinet/tcp_var.h
parenta6b0a635844a868ee7cf88c1f0682c1d92064d25 (diff)
!sack_disable -> sack_enable; ok deraadt@
Diffstat (limited to 'sys/netinet/tcp_var.h')
-rw-r--r--sys/netinet/tcp_var.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/netinet/tcp_var.h b/sys/netinet/tcp_var.h
index 3a2eb273114..b9639558ae3 100644
--- a/sys/netinet/tcp_var.h
+++ b/sys/netinet/tcp_var.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: tcp_var.h,v 1.56 2004/01/29 11:55:28 markus Exp $ */
+/* $OpenBSD: tcp_var.h,v 1.57 2004/01/31 19:40:10 markus Exp $ */
/* $NetBSD: tcp_var.h,v 1.17 1996/02/13 23:44:24 christos Exp $ */
/*
@@ -100,7 +100,7 @@ struct tcpcb {
tcp_seq iss; /* initial send sequence number */
u_long snd_wnd; /* send window */
#if 1 /*def TCP_SACK*/
- int sack_disable; /* disable SACK for this connection */
+ int sack_enable; /* enable SACK for this connection */
int snd_numholes; /* number of holes seen by sender */
struct sackhole *snd_holes; /* linked list of holes (sorted) */
#if 1 /*defined(TCP_SACK) && defined(TCP_FACK)*/